@@ -165,7 +165,7 @@ show_toolbar_cb (GtkAction * action, gpointer data)
   gboolean state;
 
   state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-  gconf_set_show_toolbar (state);
+  conf_set_show_toolbar (state);
 }
 
 
@@ -265,7 +265,7 @@ about_cb (GtkAction * action, gpointer data)
 			 "comments", _("Based on classic BSD Robots."),
 			 "authors", authors,
 			 "documenters", documenters,
-			 "translator_credits", _("translator-credits"),
+			 "translator-credits", _("translator-credits"),
 			 "logo-icon-name", "gnome-robots",
 			 "website",
 			 "http://www.gnome.org/projects/gnome-games/",
@@ -410,4 +410,6 @@ connect_toolbar_toggle (GtkWidget * toolbar)
 		    G_CALLBACK (toggle_toolbar_cb), toolbar);
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (toolbar_toggle_action),
 				properties_show_toolbar ());
+
+  toggle_toolbar_cb (GTK_TOGGLE_ACTION (toolbar_toggle_action), toolbar);
 }
